@@ -322,9 +322,18 @@ void PocketWordParser::checkUnparsed()
 			done=readSound(entry, object);
 			break;
 		}
-		case 130:
+		/* 103: 670001000400000000005a00
+		        bdbox?
+				000001000000010000000000000000000000000
+				+ flag?
+		 */
+		case 130: // find 820000000000000000000000 or 8200010000000000000000005a000000 where 5a is a 103 id
 			name="End";
 			break;
+
+		/* 131: N, Nmax?, 000000040000005f002a00d301de010000000000000000
+		   then a list a 103 id
+		*/
 		default:
 			break;
 		}
@@ -336,7 +345,7 @@ void PocketWordParser::checkUnparsed()
 			else
 				f << "Entries(" << name << "):";
 			f << "id=" << entry.id() << ",";
-			ascii().addPos(entry.begin());
+			ascii().addPos(entry.begin()-6);
 			ascii().addNote(f.str().c_str());
 		}
 		if (input->tell()!=entry.end())
@@ -679,7 +688,7 @@ bool PocketWordParser::sendParagraph(size_t paraId)
 				done=false;
 				break;
 			case 0xc2:
-				f << "[ParaUnkn" << val << "]";
+				f << "[paraUnkn=" << val << "]";
 				break;
 			// 0xc3: unsure, find one time an id to a paragraph and an id to a unexisting zone
 			case 0xc4:
@@ -1196,6 +1205,7 @@ bool PocketWordParser::readUnkn8(WPSEntry const &entry)
 	ascii().addNote(f.str().c_str());
 	return true;
 }
+
 bool PocketWordParser::readUnkn2021(WPSEntry const &entry, int type)
 {
 	// checkme follow the font name, so this can be the styles
