@@ -53,12 +53,13 @@ public:
 		explicit Position(Vec2i pos=Vec2i(-1,-1), librevenge::RVNGString const &sheetName="")
 			: m_pos(pos)
 			, m_sheetName(sheetName)
+			, m_sheetId(-1)
 		{
 		}
 		//! return true if the position is valid
 		bool valid() const
 		{
-			return m_pos[0]>=0 && m_pos[1]>=0 && !m_sheetName.empty();
+			return m_pos[0]>=0 && m_pos[1]>=0 && (!m_sheetName.empty() || m_sheetId>=0);
 		}
 		//! return true if the position is valid
 		bool valid(Position const &maxPos) const
@@ -72,7 +73,7 @@ public:
 		//! operator==
 		bool operator==(Position const &pos) const
 		{
-			return m_pos==pos.m_pos && m_sheetName==pos.m_sheetName;
+			return m_pos==pos.m_pos && m_sheetName==pos.m_sheetName && m_sheetId==pos.m_sheetId;
 		}
 		//! operator!=
 		bool operator!=(Position const &pos) const
@@ -83,6 +84,12 @@ public:
 		Vec2i m_pos;
 		//! the cell sheet name
 		librevenge::RVNGString m_sheetName;
+		/** the cell sheet id
+			\note can be used temporary if the sheet name is not known when reading a position,
+			but you must before sending a chart, go through such positions to set the final
+			spreadsheet name
+		 */
+		int m_sheetId;
 	};
 	//! a axis in a chart
 	struct Axis
