@@ -44,26 +44,31 @@
 namespace WPS8TableInternal
 {
 /** Internal: class to store a basic cell with borders */
-struct Cell : public WPSCell
+struct Cell final : public WPSCell
 {
 	//! constructor
-	explicit Cell(WPS8Table &parser) : WPSCell(), m_tableParser(parser), m_id(-1), m_strsId(-1), m_size()
+	explicit Cell(WPS8Table &parser)
+		: WPSCell()
+		, m_tableParser(parser)
+		, m_id(-1)
+		, m_strsId(-1)
+		, m_size()
 	{
 		WPSBorder emptyBorder;
 		emptyBorder.m_style = WPSBorder::None;
 		m_bordersList.resize(4, emptyBorder);
-		for (int i = 0; i < 4; i++) m_bordersSep[i] = 0.0;
+		for (float &i : m_bordersSep) i = 0.0;
 	}
 	//! virtual destructor
-	virtual ~Cell() {}
+	~Cell() final;
 
 	//! operator<<
 	friend std::ostream &operator<<(std::ostream &o, Cell const &cell);
 	//! call when a cell must be send
-	virtual bool send(WPSListenerPtr &listener)
+	bool send(WPSListenerPtr &listener) final
 	{
 		if (!listener) return true;
-		WPSContentListener *listen=dynamic_cast<WPSContentListener *>(listener.get());
+		auto *listen=dynamic_cast<WPSContentListener *>(listener.get());
 		if (!listen)
 		{
 			WPS_DEBUG_MSG(("WPS8TableInternal::Cell::send: unexpected listener\n"));
@@ -76,7 +81,7 @@ struct Cell : public WPSCell
 	}
 
 	//! call when the content of a cell must be send
-	virtual bool sendContent(WPSListenerPtr &)
+	bool sendContent(WPSListenerPtr &) final
 	{
 		m_tableParser.sendTextInCell(m_strsId, m_id);
 		return true;
@@ -93,16 +98,18 @@ struct Cell : public WPSCell
 	//! border text separator T,L,R,B ( checkme, not sure )
 	float m_bordersSep[4];
 };
-
+Cell::~Cell()
+{
+}
 //! operator<< for a Cell
 std::ostream &operator<<(std::ostream &o, Cell const &cell)
 {
 	o << reinterpret_cast<WPSCell const &>(cell);
 	if (cell.m_size.x() > 0 || cell.m_size.y() > 0) o << "size=" << cell.m_size << ",";
 	bool hasBSize = false;
-	for (int i = 0; i < 4; i++)
+	for (float i : cell.m_bordersSep)
 	{
-		if (cell.m_bordersSep[i] <= 0)
+		if (i <= 0)
 			continue;
 		hasBSize = true;
 		break;
@@ -110,8 +117,8 @@ std::ostream &operator<<(std::ostream &o, Cell const &cell)
 	if (hasBSize)
 	{
 		o << "borderSep?=[";
-		for (int i = 0; i < 4; i++)
-			if (cell.m_bordersSep[i] > 0) o << cell.m_bordersSep[i] << ",";
+		for (float i : cell.m_bordersSep)
+			if (i > 0) o << i << ",";
 			else o << "_,";
 		o << "],";
 	}
@@ -119,10 +126,15 @@ std::ostream &operator<<(std::ostream &o, Cell const &cell)
 }
 
 /** Internal: class to store a table: list of cells */
-struct Table : public WPSTable
+struct Table final : public WPSTable
 {
 	//! constructor
-	Table() : m_id(-1), m_parsed(false) {}
+	Table()
+		: m_id(-1)
+		, m_parsed(false) {}
+	Table &operator=(Table const &)=default;
+	//! destructor
+	~Table() final;
 	//! operator<<
 	friend std::ostream &operator<<(std::ostream &o, Table const &table);
 	//! the table id
@@ -131,6 +143,11 @@ struct Table : public WPSTable
 	//! a bool to know if the table has been parsed
 	mutable bool m_parsed;
 };
+
+Table::~Table()
+{
+}
+
 //! operator<< for a Table
 std::ostream &operator<<(std::ostream &o, Table const &table)
 {
@@ -148,7 +165,11 @@ std::ostream &operator<<(std::ostream &o, Table const &table)
 struct State
 {
 	//! constructor
-	State() : m_version(-1), m_numPages(0), m_tableMap(), m_MCLDTypes()
+	State()
+		: m_version(-1)
+		, m_numPages(0)
+		, m_tableMap()
+		, m_MCLDTypes()
 	{
 		initTypeMaps();
 	}
@@ -177,7 +198,7 @@ void State::initTypeMaps()
 		0x28, 0x22, 0x29, 0x22, 0x2a, 0x12, 0x2b, 0x22, 0x2c, 0x12,
 		0x31, 0x18
 	};
-	for (int i = 0; i+1 < int(sizeof(MCLDTypes)/sizeof(int)); i+=2)
+	for (int i = 0; i+1 < int(WPS_N_ELEMENTS(MCLDTypes)); i+=2)
 		m_MCLDTypes[MCLDTypes[i]] = MCLDTypes[i+1];
 
 }
@@ -186,10 +207,12 @@ void State::initTypeMaps()
 ////////////////////////////////////////////////////////////
 // constructor/destructor
 ////////////////////////////////////////////////////////////
-WPS8Table::WPS8Table(WPS8Parser &parser) :
-	m_listener(), m_mainParser(parser), m_state(), m_asciiFile(parser.ascii())
+WPS8Table::WPS8Table(WPS8Parser &parser)
+	: m_listener()
+	, m_mainParser(parser)
+	, m_state(new WPS8TableInternal::State)
+	, m_asciiFile(parser.ascii())
 {
-	m_state.reset(new WPS8TableInternal::State);
 }
 
 WPS8Table::~WPS8Table()
@@ -226,17 +249,14 @@ void WPS8Table::computePositions() const
 
 void WPS8Table::flushExtra()
 {
-	if (m_listener.get() == 0L) return;
-	typedef WPS8TableInternal::Table Table;
+	if (m_listener.get() == nullptr) return;
 
-	std::map<int, Table>::iterator pos = m_state->m_tableMap.begin();
-	while (pos != m_state->m_tableMap.end())
+	for (auto const &table : m_state->m_tableMap)
 	{
-		Table &table = pos++->second;
-		if (table.m_parsed) continue;
-		int strsid = m_mainParser.getTableSTRSId(table.m_id);
+		if (table.second.m_parsed) continue;
+		int strsid = m_mainParser.getTableSTRSId(table.second.m_id);
 		if (strsid < 0) continue;
-		sendTable(Vec2f(100.,100.),  table.m_id, strsid);
+		sendTable(Vec2f(100.,100.),  table.second.m_id, strsid);
 	}
 }
 
@@ -255,9 +275,8 @@ bool WPS8Table::sendTable(Vec2f const &siz, int tableId, int strsid, bool inText
 		WPS_DEBUG_MSG(("WPS8Table::sendTable: strsid is not set\n"));
 		return false;
 	}
-	typedef WPS8TableInternal::Table Table;
 
-	std::map<int, Table>::iterator pos = m_state->m_tableMap.find(tableId);
+	auto pos = m_state->m_tableMap.find(tableId);
 	if (pos == m_state->m_tableMap.end())
 	{
 		WPS_DEBUG_MSG(("WPS8Table::sendTable: can not find table with id=%d\n", tableId));
@@ -275,7 +294,7 @@ bool WPS8Table::sendTable(Vec2f const &siz, int tableId, int strsid, bool inText
 		return true;
 	}
 
-	Table &table = pos->second;
+	auto &table = pos->second;
 	if (table.m_parsed)
 		WPS_DEBUG_MSG(("WPS8Table::sendTable: table with id=%d is already parsed\n", tableId));
 	else
@@ -295,13 +314,12 @@ bool WPS8Table::sendTable(Vec2f const &siz, int tableId, int strsid, bool inText
 ////////////////////////////////////////////////////////////
 // find all structures which correspond to the table
 ////////////////////////////////////////////////////////////
-bool WPS8Table::readStructures(RVNGInputStreamPtr input)
+bool WPS8Table::readStructures(RVNGInputStreamPtr const &input)
 {
 	m_state->m_tableMap.clear();
 
-	WPS8Parser::NameMultiMap &nameTable = m_mainParser.getNameEntryMap();
-	WPS8Parser::NameMultiMap::iterator pos;
-	pos = nameTable.lower_bound("MCLD");
+	auto &nameTable = m_mainParser.getNameEntryMap();
+	auto pos = nameTable.lower_bound("MCLD");
 	while (pos != nameTable.end())
 	{
 		WPSEntry const &entry = pos++->second;
@@ -319,9 +337,6 @@ bool WPS8Table::readStructures(RVNGInputStreamPtr input)
 ////////////////////////////////////////////////////////////
 bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 {
-	typedef WPS8TableInternal::Cell Cell;
-	typedef WPS8TableInternal::Table Table;
-
 	if (!entry.hasType(entry.name()))
 	{
 		WPS_DEBUG_MSG(("WPS8Table::readMCLD: warning: MCLD name=%s, type=%s\n",
@@ -335,7 +350,7 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 
 	if (length < 24)
 	{
-		WPS_DEBUG_MSG(("WPS8Table::readMCLD: warning: MCLD length=0x%lx\n", (unsigned long) length));
+		WPS_DEBUG_MSG(("WPS8Table::readMCLD: warning: MCLD length=0x%lx\n", static_cast<unsigned long>(length)));
 
 		return false;
 	}
@@ -344,8 +359,8 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 	input->seek(page_offset, librevenge::RVNG_SEEK_SET);
 
 	libwps::DebugStream f;
-	int mZone = (int) libwps::read32(input);
-	int nTables = (int) libwps::read32(input);
+	auto mZone = int(libwps::read32(input));
+	auto nTables = int(libwps::read32(input));
 
 	f << "maxUnknown=" << mZone << ", nTables= " << nTables;
 	if ((6+long(nTables)) * 4 > length) return false;
@@ -354,7 +369,7 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 	std::vector<int> listIds;
 	for (int i = 0; i < nTables; i++)
 	{
-		int val = (int) libwps::read32(input);
+		auto val = int(libwps::read32(input));
 		listIds.push_back(val);
 		f << val << ",";
 	}
@@ -366,10 +381,10 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 	int mCounter = -1;
 	bool ok = true;
 
-	static char const *(borderNames[]) = { "T", "L", "R", "B" };
-	static int const(borderPos[]) =
+	static char const *borderNames[] = { "T", "L", "R", "B" };
+	static int const borderPos[] =
 	{ WPSBorder::Top, WPSBorder::Left, WPSBorder::Right, WPSBorder::Bottom};
-	static int const(borderBit[]) =
+	static int const borderBit[] =
 	{
 		WPSBorder::TopBit, WPSBorder::LeftBit,
 		WPSBorder::RightBit, WPSBorder::BottomBit
@@ -387,7 +402,7 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 		lastPosOk = input->tell();
 
 		WPS8Struct::FileData tableData;
-		int sz = (int) libwps::read16(input);
+		auto sz = int(libwps::read16(input));
 		if (sz < 2 || lastPosOk+sz > endPage)
 		{
 			ok = false;
@@ -407,7 +422,7 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 		if (tableId < 0) f << "MCLD/Table[###unknownId]:";
 		else f << "MCLD/Table" << listIds[size_t(mCounter)]<<":";
 
-		int N = (int) libwps::readU32(input);
+		auto N = int(libwps::readU32(input));
 		f << " nCells=" << N;
 		if (N < 0 || N > 100)
 		{
@@ -415,19 +430,17 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 			break;
 		}
 
-		Table table;
+		WPS8TableInternal::Table table;
 		table.m_id = tableId;
 
 		// point dim seems odd, we will need to update them
 		Vec2f totalRealDim(0,0), totalDataDim(0,0);
 
-		size_t numChild = tableData.m_recursData.size();
-		if (numChild)
+		if (!tableData.m_recursData.empty())
 		{
 			f << ",(";
-			for (size_t c = 0; c < numChild; c++)
+			for (auto const &dt : tableData.m_recursData)
 			{
-				WPS8Struct::FileData const &dt = tableData.m_recursData[c];
 				if (dt.isBad()) continue;
 				int const expectedTypes[] = { 2, 0x22 };
 				if (dt.id() < 0 || dt.id() > 1)
@@ -467,7 +480,7 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 		for (size_t actualCell = 0; actualCell < size_t(N); actualCell++)
 		{
 			lastPosOk = input->tell();
-			sz = (int) libwps::read16(input);
+			sz = int(libwps::read16(input));
 			if (sz < 2 || lastPosOk+sz > endPage)
 			{
 				ok = false;
@@ -484,8 +497,6 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 				error = f.str();
 			}
 
-			size_t nChild = mainData.m_recursData.size();
-
 			// original position in point ( checkme)
 			float dim[4] = {  0, 0, 0, 0 };
 
@@ -494,16 +505,15 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 			if (tableId >= 0) f << tableId;
 			f << "(Cell" << actualCell <<"):";
 
-			Cell *cell = new Cell(*this);
+			auto cell = std::make_shared<WPS8TableInternal::Cell>(*this);
 			WPSCellPtr cellPtr(cell);
 			cell->m_id = int(actualCell);
 
 			libwps::DebugStream f2;
 			WPSColor cellColor[] = { WPSColor::black(), WPSColor::white() };
 
-			for (size_t c = 0; c < nChild; c++)
+			for (auto &dt : mainData.m_recursData)
 			{
-				WPS8Struct::FileData const &dt = mainData.m_recursData[c];
 				if (dt.isBad()) continue;
 				if (m_state->m_MCLDTypes.find(dt.id())==m_state->m_MCLDTypes.end())
 				{
@@ -548,7 +558,7 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 					f2 << "f" << dt.id() << "=" << std::hex << dt.m_value << std::dec << ",";
 					break;
 				case 0x13:   //find -1|6 here
-					f2 << "f" << dt.id() << "=" << (int)(int8_t)(dt.m_value) << ",";
+					f2 << "f" << dt.id() << "=" << int(int8_t(dt.m_value)) << ",";
 					break;
 				case 0x1d: // first color
 				case 0x1e: // second color
@@ -631,13 +641,13 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 					switch (dt.m_value)
 					{
 					case 0:
-						cell->setVAlignement(WPSCellFormat::VALIGN_TOP);
+						cell->setVAlignment(WPSCellFormat::VALIGN_TOP);
 						break;
 					case 1:
-						cell->setVAlignement(WPSCellFormat::VALIGN_CENTER);
+						cell->setVAlignment(WPSCellFormat::VALIGN_CENTER);
 						break;
 					case 2:
-						cell->setVAlignement(WPSCellFormat::VALIGN_BOTTOM);
+						cell->setVAlignment(WPSCellFormat::VALIGN_BOTTOM);
 						break;
 					default:
 						if (dt.m_value > -10 && dt.m_value < 10)
@@ -687,7 +697,7 @@ bool WPS8Table::readMCLD(RVNGInputStreamPtr input, WPSEntry const &entry)
 		if (totalDataDim[1] > 0) factor[1] = 72.f*totalRealDim[1]/totalDataDim[1];
 		for (int c = 0; c < table.numCells(); c++)
 		{
-			WPSCellPtr cell = table.getCell(c);
+			auto cell = table.getCell(c);
 			if (!cell) continue;
 			WPSBox2f box=cell->box();
 			cell->setBox(WPSBox2f(Vec2f(box[0][0]*factor[0], box[0][1]*factor[1]),
